# CellPhoneDB Resources
## PPI resources:

* [IUPHAR](http://www.guidetopharmacology.org/)
* [iMEX](https://www.imexconsortium.org/) Orchard S et al., Protein interaction data curation: the International Molecular Exchange (IMEx) consortium. Nat Methods. 2012 Apr;9(4):345-50. 
* [Intact](https://www.ebi.ac.uk/intact/) Orchard S et al., The MIntAct project--IntAct as a common curation platform for 11 molecular interaction databases. Nucleic Acids Research 42: D358-63 (2013)
* [InnateDB](http://www.innatedb.com/) Breuer et al., InnateDB: systems biology of innate immunity and beyond - recent updates and continuing curation. Nucleic Acids Research 41:D1 (2013)
* [DIP](http://dip.mbi.ucla.edu/dip/)  Salwinski L, et al., The Database of Interacting Proteins: 2004 update. Nucleic Acids Research 32:D449-51 (2004)
* [MINT](https://mint.bio.uniroma2.it/) Licata L, et al., MINT, the molecular interaction database: 2012 update. Nucleic Acids Research 40:D857-61 (2012)
* [I2D](http://ophid.utoronto.ca/ophidv2.204/) Brown, K.R., and Jurisica, I. Unequal evolutionary conservation of human protein interactions in interologous networks. Genome Biology, 8(5):R95 (2007)
* [MatrixDB](http://matrixdb.univ-lyon1.fr/) Launay G et al., MatrixDB, the extracellular matrix interaction database: updated content, a new navigator and expanded functionalities. Nucleic Acids Research 43:D321-7 (2015)
* [HPIDB](http://hpidb.igbb.msstate.edu/index.html) HPIDB 2.0: a curated database for host–pathogen interactions. Ammari MG Database, Volume 2016 (2016)

## Other resources:

* [Uniprot](https://www.uniprot.org/)  UniProt: the universal protein knowledgebase. The UniProt Consortium. Nucleic Acids Research 45: D158-D169 (2017)
* [Ensembl](https://www.ensembl.org/)  Ensembl 2018. Zerbino DR et al.,. Nucleic Acids Research 46: D754–D761 (2018)
* [PDB](https://www.rcsb.org/) Rose PW et al., The RCSB protein data bank: integrative view of protein, gene and 3D structural information [Nucleic Acids Research, 45: D271-D281](http://dx.doi.org/10.1093/nar/gkw1000) (2017)